mask

Function mask 

pub const fn mask(source: usize) -> i64
The value that enables one source when written to ie.

A power of three, not of two, because the position is a trit position: enabling source k means putting a +1 in trit k.